@@ -1,11 +1,9 @@
 // Copyright (C) 2020 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
-// Qt-Security score:significant
 
 #include "qqmljscompiler_p.h"
 
 #include <private/qqmlirbuilder_p.h>
-#include <private/qqmljsaotirbuilder_p.h>
 #include <private/qqmljsbasicblocks_p.h>
 #include <private/qqmljscodegenerator_p.h>
 #include <private/qqmljscompilerstats_p.h>
@@ -23,7 +21,6 @@
 #include <QtCore/qfile.h>
 #include <QtCore/qfileinfo.h>
 #include <QtCore/qloggingcategory.h>
-#include <QtCore/qelapsedtimer.h>
 
 #include <QtQml/private/qqmlsignalnames_p.h>
 
@@ -172,7 +169,7 @@ private:
     const QmlIR::Function *m_function = nullptr;
 };
 
-bool qCompileQmlFile(const QString &inputFileName, QQmlJSSaveFunction saveFunction,
+bool qCompileQmlFile(const QString &inputFileName, const QQmlJSSaveFunction &saveFunction,
                      QQmlJSAotCompiler *aotCompiler, QQmlJSCompileError *error,
                      bool storeSourceLocation, QV4::Compiler::CodegenWarningInterface *wInterface,
                      const QString *fileContents)
@@ -183,7 +180,7 @@ bool qCompileQmlFile(const QString &inputFileName, QQmlJSSaveFunction saveFuncti
 }
 
 bool qCompileQmlFile(QmlIR::Document &irDocument, const QString &inputFileName,
-                     QQmlJSSaveFunction saveFunction, QQmlJSAotCompiler *aotCompiler,
+                     const QQmlJSSaveFunction &saveFunction, QQmlJSAotCompiler *aotCompiler,
                      QQmlJSCompileError *error, bool storeSourceLocation,
                      QV4::Compiler::CodegenWarningInterface *wInterface, const QString *fileContents)
 {
@@ -205,11 +202,9 @@ bool qCompileQmlFile(QmlIR::Document &irDocument, const QString &inputFileName,
     }
 
     {
-        // For now, only use the AOT IRBuilder when linting
-        std::unique_ptr<QmlIR::IRBuilder> irBuilder = aotCompiler && aotCompiler->isLintCompiler()
-                ? std::make_unique<QQmlJSAOTIRBuilder>() : std::make_unique<QmlIR::IRBuilder>();
-        if (!irBuilder->generateFromQml(sourceCode, inputFileName, &irDocument)) {
-            error->appendDiagnostics(inputFileName, irBuilder->errors);
+        QmlIR::IRBuilder irBuilder;
+        if (!irBuilder.generateFromQml(sourceCode, inputFileName, &irDocument)) {
+            error->appendDiagnostics(inputFileName, irBuilder.errors);
             return false;
         }
     }
@@ -324,9 +319,6 @@ bool qCompileQmlFile(QmlIR::Document &irDocument, const QString &inputFileName,
                                            << irDocument.stringAt(binding->propertyNameIndex);
                     result = aotCompiler->compileBinding(context, *binding, node);
                 } else if (const auto *function = bindingOrFunction.function()) {
-                    if (!aotCompiler->isLintCompiler() && !function->isQmlFunction)
-                        return;
-
                     Q_ASSERT(quint32(functionsToCompile.size()) > function->index);
                     auto *node = functionsToCompile[function->index].node;
                     Q_ASSERT(node);
@@ -379,8 +371,8 @@ bool qCompileQmlFile(QmlIR::Document &irDocument, const QString &inputFileName,
 }
 
 bool qCompileJSFile(
-        const QString &inputFileName, const QString &inputFileUrl, QQmlJSSaveFunction saveFunction,
-        QQmlJSCompileError *error)
+        const QString &inputFileName, const QString &inputFileUrl,
+        const QQmlJSSaveFunction &saveFunction, QQmlJSCompileError *error)
 {
     Q_UNUSED(inputFileUrl);
 
@@ -637,8 +629,7 @@ void QQmlJSAotCompiler::setDocument(
         m_logger->setFilePath(resourcePathInfo.fileName());
     m_logger->setCode(irDocument->code);
     m_unitGenerator = &irDocument->jsGenerator;
-    QQmlJSScope::Ptr target = QQmlJSScope::create();
-    QQmlJSImportVisitor visitor(target, m_importer, m_logger,
+    QQmlJSImportVisitor visitor(m_importer, m_logger,
                                 resourcePathInfo.canonicalPath() + u'/',
                                 m_qmldirFiles);
     m_typeResolver.init(&visitor, irDocument->program);
@@ -810,16 +801,15 @@ QQmlJSAotFunction QQmlJSAotCompiler::doCompileAndRecordAotStats(
         const QV4::Compiler::Context *context, QQmlJSCompilePass::Function *function,
         const QString &name, QQmlJS::SourceLocation location)
 {
-    QElapsedTimer timer {};
-    timer.start();
+    auto t1 = std::chrono::high_resolution_clock::now();
     QQmlJSAotFunction result;
     if (!m_logger->currentFunctionHasCompileError())
         result = doCompile(context, function);
-    auto elapsed = std::chrono::milliseconds { timer.elapsed() };
+    auto t2 = std::chrono::high_resolution_clock::now();
 
     if (QQmlJS::QQmlJSAotCompilerStats::recordAotStats()) {
         QQmlJS::AotStatsEntry entry;
-        entry.codegenDuration = elapsed;
+        entry.codegenDuration = std::chrono::duration_cast<std::chrono::microseconds>(t2 - t1);
         entry.functionName = name;
         entry.message = m_logger->currentFunctionWasSkipped()
                 ? m_logger->currentFunctionCompileSkipMessage()
